<?php
require 'vendor/autoload.php'; 

use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use PhpOffice\PhpSpreadsheet\Style\Fill;
use PhpOffice\PhpSpreadsheet\Style\Border;
use PhpOffice\PhpSpreadsheet\Style\Alignment;

require_once 'validaciones/conexion.php';

$database = new Database();
$db = $database->getConnection();

// Consulta a la base de datos para obtener los datos que deseas exportar
$query = "SELECT * FROM clientes"; // Ajusta la consulta según tus necesidades
$stmt = $db->prepare($query);
$stmt->execute();
$data = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Crear un nuevo objeto Spreadsheet
$spreadsheet = new Spreadsheet();
$sheet = $spreadsheet->getActiveSheet();

// Establecer los encabezados
$headers = array('NRO', 'DNI', 'Nombres', 'Correo', 'Número Boleta', 'Lugar Compra');
$sheet->fromArray($headers, NULL, 'A1');

// Aplicar estilos a los encabezados
$headerRange = 'A1:F1'; // Rango de encabezados
$sheet->getStyle($headerRange)->getFill()->setFillType(Fill::FILL_SOLID)->getStartColor()->setARGB('FFFFE0'); // Color de fondo claro
$sheet->getStyle($headerRange)->getFont()->setBold(true); // Fuente en negrita
$sheet->getStyle($headerRange)->getAlignment()->setHorizontal(Alignment::HORIZONTAL_CENTER); // Alinear texto al centro
$sheet->getStyle($headerRange)->getBorders()->getAllBorders()->setBorderStyle(Border::BORDER_THIN); // Bordes finos

// Ajustar el ancho de las columnas
$columnWidths = [10, 20, 30, 30, 20, 30]; // Anchos de columnas personalizados
foreach (range('A', 'F') as $index => $column) {
    $sheet->getColumnDimension($column)->setWidth($columnWidths[$index]);
}

// Escribir los datos en el archivo
$rowNumber = 2; // Empezar a escribir en la segunda fila
foreach ($data as $index => $row) {
    $sheet->fromArray(array_values($row), NULL, 'A' . $rowNumber++);
    $sheet->setCellValue('A' . $rowNumber, $index + 1); // Agregar número de fila
}

// Crear el escritor y guardar el archivo Excel
$writer = new Xlsx($spreadsheet);
$filename = 'clientes_' . date('Ymd') . '.xlsx'; // Nombre del archivo

header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
header('Content-Disposition: attachment;filename="' . $filename . '"');
header('Cache-Control: max-age=0');

$writer->save('php://output');
exit;
?>
